@@ -13,6 +13,7 @@ import datetime as dt
 
 
 from flashcam.version import __version__
+import os
 
 class Stream_Enhancer:
     """
@@ -53,6 +54,18 @@ class Stream_Enhancer:
     avi_last = dt.datetime.now() - dt.timedelta(seconds=90000)
     aviopened_laps = False
 
+    # -- age of frame for speed
+    camera_age = 0
+    camera_start = dt.datetime.now()
+
+    # -- subtraction of mask
+    frame_bg = None
+    sub_bg = False
+
+    # background path
+    BGFILE = os.path.expanduser('~/.config/flashcam/background.jpg')
+
+
     def RC_COLOR(self,row,col):
         if not self.frame_ok: return  # B  G R
         if row==0 and col==0: return (0,0,0)
@@ -310,6 +323,30 @@ class Stream_Enhancer:
 #-------------------------------------------- ENDOF LABELS----------
 
 
+    def subtract(self):
+        if self.frame_bg is None:
+            if os.path.exists( self.BGFILE ):
+                self.frame_bg = cv2.imread( self.BGFILE )
+                print("OLD BACKGROUND IMAGE FOUND", self.frame_bg.shape)
+            else:
+                return
+        frame1 = cv2.subtract(self.frame , self.frame_bg ) #, mask = frame_mask
+        # frame 1 is difference...
+        frame1[:22,:]  = self.frame [:22,:]
+        frame1[-22:,:] = self.frame [-22:,:]
+        self.frame = frame1
+
+
+
+    def translate(self, speedx = -0.35,  speedy = -0.015 ):
+        self.camera_age = (dt.datetime.now() - self.camera_start ).total_seconds()
+        dwidth = -0.35 * self.camera_age  #negative up
+        dheight = -0.015 * self.camera_age  # positive down
+        T = np.float32([[1, 0, dwidth], [0, 1, dheight]])
+        shifted = cv2.warpAffine(self.frame, T, (self.frame.shape[1], self.frame.shape[0]))
+        # print( T )
+        self.frame = shifted
+
 
 
     def crosson(self,  dix, diy):
@@ -568,6 +605,7 @@ class Stream_Enhancer:
         """
 
         """
+        #print("i... save_avi", seconds, name)
         # -------------- one shot
         if seconds == 0:
             return
@@ -576,6 +614,11 @@ class Stream_Enhancer:
                 filename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
                 me = socket.gethostname()
                 filename = f"{me}{name}_{filename}.avi"
+                filename = os.path.expanduser("~/"+filename)
+                print(filename)
+                print(filename)
+                print(filename)
+                print(filename)
 
                 fourcc = cv2.VideoWriter_fourcc(*'XVID')
                 self.aviout = cv2.VideoWriter( filename , fourcc , 25.0, (640,480))
@@ -588,6 +631,11 @@ class Stream_Enhancer:
                 filename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
                 me = socket.gethostname()
                 filename = f"{me}_laps{seconds:04d}_{filename}.avi"
+                filename = os.path.expanduser("~/"+filename)
+                print(filename)
+                print(filename)
+                print(filename)
+                print(filename)
 
                 fourcc = cv2.VideoWriter_fourcc(*'XVID')
                 self.aviout_laps = cv2.VideoWriter( filename , fourcc , 10.0, (640,480))
