@@ -260,9 +260,9 @@ def display2(videodev, save = False,
                                     bytex = bytex[b+2:]
                                     frame = cv2.imdecode(np.frombuffer(jpg, dtype=np.uint8), cv2.IMREAD_COLOR)
                                     ret_val=1
-                                    print("got  Size={:6.0f}kB {:6.0f}kB/s {}fps {} {}".format(
+                                    print("got  Size={:6.0f}kB {:4.1f}MB/s {}fps {} {}".format(
                                         len(bytex)/1024,
-                                        BPSlast,
+                                        BPSlast*8/1024,
                                         FPSlast,
                                         datetime.datetime.now(),
                                         sfilenamea
